Installation
============

Use `pip`_ to install Flask-Dance. To use basic functionality, run this:

.. code-block:: bash

    $ pip install Flask-Dance

To also use the :ref:`SQLAlchemy backend <sqlalchemy-backend>`, specify the
``sqla`` extra, like this:

.. code-block:: bash

    $ pip install Flask-Dance[sqla]

.. _pip: https://pip.pypa.io

Library development
===================

Use `tox`_ to execute unit tests on multiple python versions. You can also use
`tox`_ to build the documentation.


.. _tox: https://tox.readthedocs.io/
